# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/slashing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/slashing/v1beta1/slashing.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x02\n\x14ValidatorSigningInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12-\n\x0cstart_height\x18\x02 \x01(\x03\x42\x17\xf2\xde\x1f\x13yaml:\"start_height\"\x12-\n\x0cindex_offset\x18\x03 \x01(\x03\x42\x17\xf2\xde\x1f\x13yaml:\"index_offset\"\x12Q\n\x0cjailed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1f\xf2\xde\x1f\x13yaml:\"jailed_until\"\x90\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x12\n\ntombstoned\x18\x05 \x01(\x08\x12?\n\x15missed_blocks_counter\x18\x06 \x01(\x03\x42 \xf2\xde\x1f\x1cyaml:\"missed_blocks_counter\":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\x88\x04\n\x06Params\x12=\n\x14signed_blocks_window\x18\x01 \x01(\x03\x42\x1f\xf2\xde\x1f\x1byaml:\"signed_blocks_window\"\x12m\n\x15min_signed_per_window\x18\x02 \x01(\x0c\x42N\xf2\xde\x1f\x1cyaml:\"min_signed_per_window\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x64\n\x16\x64owntime_jail_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB)\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x1dyaml:\"downtime_jail_duration\"\x12w\n\x1aslash_fraction_double_sign\x18\x04 \x01(\x0c\x42S\xf2\xde\x1f!yaml:\"slash_fraction_double_sign\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12q\n\x17slash_fraction_downtime\x18\x05 \x01(\x0c\x42P\xf2\xde\x1f\x1eyaml:\"slash_fraction_downtime\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x33Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01\x62\x06proto3')



_VALIDATORSIGNINGINFO = DESCRIPTOR.message_types_by_name['ValidatorSigningInfo']
_PARAMS = DESCRIPTOR.message_types_by_name['Params']
ValidatorSigningInfo = _reflection.GeneratedProtocolMessageType('ValidatorSigningInfo', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORSIGNINGINFO,
  '__module__' : 'cosmos.slashing.v1beta1.slashing_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.ValidatorSigningInfo)
  })
_sym_db.RegisterMessage(ValidatorSigningInfo)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cosmos.slashing.v1beta1.slashing_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\250\342\036\001'
  _VALIDATORSIGNINGINFO.fields_by_name['start_height']._options = None
  _VALIDATORSIGNINGINFO.fields_by_name['start_height']._serialized_options = b'\362\336\037\023yaml:\"start_height\"'
  _VALIDATORSIGNINGINFO.fields_by_name['index_offset']._options = None
  _VALIDATORSIGNINGINFO.fields_by_name['index_offset']._serialized_options = b'\362\336\037\023yaml:\"index_offset\"'
  _VALIDATORSIGNINGINFO.fields_by_name['jailed_until']._options = None
  _VALIDATORSIGNINGINFO.fields_by_name['jailed_until']._serialized_options = b'\362\336\037\023yaml:\"jailed_until\"\220\337\037\001\310\336\037\000'
  _VALIDATORSIGNINGINFO.fields_by_name['missed_blocks_counter']._options = None
  _VALIDATORSIGNINGINFO.fields_by_name['missed_blocks_counter']._serialized_options = b'\362\336\037\034yaml:\"missed_blocks_counter\"'
  _VALIDATORSIGNINGINFO._options = None
  _VALIDATORSIGNINGINFO._serialized_options = b'\350\240\037\001\230\240\037\000'
  _PARAMS.fields_by_name['signed_blocks_window']._options = None
  _PARAMS.fields_by_name['signed_blocks_window']._serialized_options = b'\362\336\037\033yaml:\"signed_blocks_window\"'
  _PARAMS.fields_by_name['min_signed_per_window']._options = None
  _PARAMS.fields_by_name['min_signed_per_window']._serialized_options = b'\362\336\037\034yaml:\"min_signed_per_window\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['downtime_jail_duration']._options = None
  _PARAMS.fields_by_name['downtime_jail_duration']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\035yaml:\"downtime_jail_duration\"'
  _PARAMS.fields_by_name['slash_fraction_double_sign']._options = None
  _PARAMS.fields_by_name['slash_fraction_double_sign']._serialized_options = b'\362\336\037!yaml:\"slash_fraction_double_sign\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['slash_fraction_downtime']._options = None
  _PARAMS.fields_by_name['slash_fraction_downtime']._serialized_options = b'\362\336\037\036yaml:\"slash_fraction_downtime\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _VALIDATORSIGNINGINFO._serialized_start=155
  _VALIDATORSIGNINGINFO._serialized_end=466
  _PARAMS._serialized_start=469
  _PARAMS._serialized_end=989
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/vpool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vpool/v1/vpool.proto\x12\x0fnibiru.vpool.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x13\x63ommon/common.proto\"\xd6\x01\n\x0fReserveSnapshot\x12J\n\x12\x62\x61se_asset_reserve\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13quote_asset_reserve\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0ctimestamp_ms\x18\x03 \x01(\x03\x12\x14\n\x0c\x62lock_number\x18\x04 \x01(\x03\"\xba\x03\n\x04Pool\x12,\n\x04pair\x18\x01 \x01(\x0b\x32\x18.nibiru.common.AssetPairB\x04\xc8\xde\x1f\x00\x12J\n\x12\x62\x61se_asset_reserve\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13quote_asset_reserve\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12I\n\x11trade_limit_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x66luctuation_limit_ratio\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17max_oracle_spread_ratio\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00*M\n\tDirection\x12\x19\n\x15\x44IRECTION_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x41\x44\x44_TO_POOL\x10\x01\x12\x14\n\x10REMOVE_FROM_POOL\x10\x02*g\n\x0eTwapCalcOption\x12 \n\x1cTWAP_CALC_OPTION_UNSPECIFIED\x10\x00\x12\x08\n\x04SPOT\x10\x01\x12\x14\n\x10QUOTE_ASSET_SWAP\x10\x02\x12\x13\n\x0f\x42\x41SE_ASSET_SWAP\x10\x03\x42-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')

_DIRECTION = DESCRIPTOR.enum_types_by_name['Direction']
Direction = enum_type_wrapper.EnumTypeWrapper(_DIRECTION)
_TWAPCALCOPTION = DESCRIPTOR.enum_types_by_name['TwapCalcOption']
TwapCalcOption = enum_type_wrapper.EnumTypeWrapper(_TWAPCALCOPTION)
DIRECTION_UNSPECIFIED = 0
ADD_TO_POOL = 1
REMOVE_FROM_POOL = 2
TWAP_CALC_OPTION_UNSPECIFIED = 0
SPOT = 1
QUOTE_ASSET_SWAP = 2
BASE_ASSET_SWAP = 3


_RESERVESNAPSHOT = DESCRIPTOR.message_types_by_name['ReserveSnapshot']
_POOL = DESCRIPTOR.message_types_by_name['Pool']
ReserveSnapshot = _reflection.GeneratedProtocolMessageType('ReserveSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _RESERVESNAPSHOT,
  '__module__' : 'vpool.v1.vpool_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.ReserveSnapshot)
  })
_sym_db.RegisterMessage(ReserveSnapshot)

Pool = _reflection.GeneratedProtocolMessageType('Pool', (_message.Message,), {
  'DESCRIPTOR' : _POOL,
  '__module__' : 'vpool.v1.vpool_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.Pool)
  })
_sym_db.RegisterMessage(Pool)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _RESERVESNAPSHOT.fields_by_name['base_asset_reserve']._options = None
  _RESERVESNAPSHOT.fields_by_name['base_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _RESERVESNAPSHOT.fields_by_name['quote_asset_reserve']._options = None
  _RESERVESNAPSHOT.fields_by_name['quote_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POOL.fields_by_name['pair']._options = None
  _POOL.fields_by_name['pair']._serialized_options = b'\310\336\037\000'
  _POOL.fields_by_name['base_asset_reserve']._options = None
  _POOL.fields_by_name['base_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POOL.fields_by_name['quote_asset_reserve']._options = None
  _POOL.fields_by_name['quote_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POOL.fields_by_name['trade_limit_ratio']._options = None
  _POOL.fields_by_name['trade_limit_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POOL.fields_by_name['fluctuation_limit_ratio']._options = None
  _POOL.fields_by_name['fluctuation_limit_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POOL.fields_by_name['max_oracle_spread_ratio']._options = None
  _POOL.fields_by_name['max_oracle_spread_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DIRECTION._serialized_start=773
  _DIRECTION._serialized_end=850
  _TWAPCALCOPTION._serialized_start=852
  _TWAPCALCOPTION._serialized_end=955
  _RESERVESNAPSHOT._serialized_start=112
  _RESERVESNAPSHOT._serialized_end=326
  _POOL._serialized_start=329
  _POOL._serialized_end=771
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stablecoin/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import (
    pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2,
)
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from stablecoin import params_pb2 as stablecoin_dot_params__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16stablecoin/query.proto\x12\x14nibiru.stablecoin.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17stablecoin/params.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1c.nibiru.stablecoin.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aQueryModuleAccountBalances\"\xa2\x01\n\"QueryModuleAccountBalancesResponse\x12|\n\x17module_account_balances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB@\xf2\xde\x1f\x0cyaml:\"coins\"\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x1a\n\x18QueryCirculatingSupplies\"\x80\x01\n QueryCirculatingSuppliesResponse\x12-\n\x04nibi\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12-\n\x04nusd\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"K\n\x14QueryGovToMintStable\x12\x33\n\ncollateral\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"L\n\x1cQueryGovToMintStableResponse\x12,\n\x03gov\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xe5\x01\n\x12LiquidityRatioInfo\x12G\n\x0fliquidity_ratio\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nupper_band\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nlower_band\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\" \n\x1eQueryLiquidityRatioInfoRequest\"_\n\x1fQueryLiquidityRatioInfoResponse\x12<\n\x04info\x18\x01 \x01(\x0b\x32(.nibiru.stablecoin.v1.LiquidityRatioInfoB\x04\xc8\xde\x1f\x00\x32\xa9\x05\n\x05Query\x12\x80\x01\n\x06Params\x12(.nibiru.stablecoin.v1.QueryParamsRequest\x1a).nibiru.stablecoin.v1.QueryParamsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/nibiru/stablecoin/params\x12\xb6\x01\n\x15ModuleAccountBalances\x12\x30.nibiru.stablecoin.v1.QueryModuleAccountBalances\x1a\x38.nibiru.stablecoin.v1.QueryModuleAccountBalancesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/nibiru/stablecoin/module_account_balance\x12\xae\x01\n\x13\x43irculatingSupplies\x12..nibiru.stablecoin.v1.QueryCirculatingSupplies\x1a\x36.nibiru.stablecoin.v1.QueryCirculatingSuppliesResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/nibiru/stablecoin/circulating_supplies\x12\xb2\x01\n\x12LiquidityRatioInfo\x12\x34.nibiru.stablecoin.v1.QueryLiquidityRatioInfoRequest\x1a\x35.nibiru.stablecoin.v1.QueryLiquidityRatioInfoResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/nibiru/stablecoin/liquidity_ratio_infoB2Z0github.com/NibiruChain/nibiru/x/stablecoin/typesb\x06proto3'
)


_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYMODULEACCOUNTBALANCES = DESCRIPTOR.message_types_by_name['QueryModuleAccountBalances']
_QUERYMODULEACCOUNTBALANCESRESPONSE = DESCRIPTOR.message_types_by_name['QueryModuleAccountBalancesResponse']
_QUERYCIRCULATINGSUPPLIES = DESCRIPTOR.message_types_by_name['QueryCirculatingSupplies']
_QUERYCIRCULATINGSUPPLIESRESPONSE = DESCRIPTOR.message_types_by_name['QueryCirculatingSuppliesResponse']
_QUERYGOVTOMINTSTABLE = DESCRIPTOR.message_types_by_name['QueryGovToMintStable']
_QUERYGOVTOMINTSTABLERESPONSE = DESCRIPTOR.message_types_by_name['QueryGovToMintStableResponse']
_LIQUIDITYRATIOINFO = DESCRIPTOR.message_types_by_name['LiquidityRatioInfo']
_QUERYLIQUIDITYRATIOINFOREQUEST = DESCRIPTOR.message_types_by_name['QueryLiquidityRatioInfoRequest']
_QUERYLIQUIDITYRATIOINFORESPONSE = DESCRIPTOR.message_types_by_name['QueryLiquidityRatioInfoResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryParamsRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPARAMSREQUEST,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryParamsRequest)
    },
)
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryParamsResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPARAMSRESPONSE,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryParamsResponse)
    },
)
_sym_db.RegisterMessage(QueryParamsResponse)

QueryModuleAccountBalances = _reflection.GeneratedProtocolMessageType(
    'QueryModuleAccountBalances',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYMODULEACCOUNTBALANCES,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryModuleAccountBalances)
    },
)
_sym_db.RegisterMessage(QueryModuleAccountBalances)

QueryModuleAccountBalancesResponse = _reflection.GeneratedProtocolMessageType(
    'QueryModuleAccountBalancesResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYMODULEACCOUNTBALANCESRESPONSE,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryModuleAccountBalancesResponse)
    },
)
_sym_db.RegisterMessage(QueryModuleAccountBalancesResponse)

QueryCirculatingSupplies = _reflection.GeneratedProtocolMessageType(
    'QueryCirculatingSupplies',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYCIRCULATINGSUPPLIES,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryCirculatingSupplies)
    },
)
_sym_db.RegisterMessage(QueryCirculatingSupplies)

QueryCirculatingSuppliesResponse = _reflection.GeneratedProtocolMessageType(
    'QueryCirculatingSuppliesResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYCIRCULATINGSUPPLIESRESPONSE,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryCirculatingSuppliesResponse)
    },
)
_sym_db.RegisterMessage(QueryCirculatingSuppliesResponse)

QueryGovToMintStable = _reflection.GeneratedProtocolMessageType(
    'QueryGovToMintStable',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYGOVTOMINTSTABLE,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryGovToMintStable)
    },
)
_sym_db.RegisterMessage(QueryGovToMintStable)

QueryGovToMintStableResponse = _reflection.GeneratedProtocolMessageType(
    'QueryGovToMintStableResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYGOVTOMINTSTABLERESPONSE,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryGovToMintStableResponse)
    },
)
_sym_db.RegisterMessage(QueryGovToMintStableResponse)

LiquidityRatioInfo = _reflection.GeneratedProtocolMessageType(
    'LiquidityRatioInfo',
    (_message.Message,),
    {
        'DESCRIPTOR': _LIQUIDITYRATIOINFO,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.LiquidityRatioInfo)
    },
)
_sym_db.RegisterMessage(LiquidityRatioInfo)

QueryLiquidityRatioInfoRequest = _reflection.GeneratedProtocolMessageType(
    'QueryLiquidityRatioInfoRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYLIQUIDITYRATIOINFOREQUEST,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryLiquidityRatioInfoRequest)
    },
)
_sym_db.RegisterMessage(QueryLiquidityRatioInfoRequest)

QueryLiquidityRatioInfoResponse = _reflection.GeneratedProtocolMessageType(
    'QueryLiquidityRatioInfoResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYLIQUIDITYRATIOINFORESPONSE,
        '__module__': 'stablecoin.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.QueryLiquidityRatioInfoResponse)
    },
)
_sym_db.RegisterMessage(QueryLiquidityRatioInfoResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z0github.com/NibiruChain/nibiru/x/stablecoin/types'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
    _QUERYMODULEACCOUNTBALANCESRESPONSE.fields_by_name['module_account_balances']._options = None
    _QUERYMODULEACCOUNTBALANCESRESPONSE.fields_by_name[
        'module_account_balances'
    ]._serialized_options = (
        b'\362\336\037\014yaml:\"coins\"\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
    )
    _QUERYCIRCULATINGSUPPLIESRESPONSE.fields_by_name['nibi']._options = None
    _QUERYCIRCULATINGSUPPLIESRESPONSE.fields_by_name['nibi']._serialized_options = b'\310\336\037\000'
    _QUERYCIRCULATINGSUPPLIESRESPONSE.fields_by_name['nusd']._options = None
    _QUERYCIRCULATINGSUPPLIESRESPONSE.fields_by_name['nusd']._serialized_options = b'\310\336\037\000'
    _QUERYGOVTOMINTSTABLE.fields_by_name['collateral']._options = None
    _QUERYGOVTOMINTSTABLE.fields_by_name['collateral']._serialized_options = b'\310\336\037\000'
    _QUERYGOVTOMINTSTABLERESPONSE.fields_by_name['gov']._options = None
    _QUERYGOVTOMINTSTABLERESPONSE.fields_by_name['gov']._serialized_options = b'\310\336\037\000'
    _LIQUIDITYRATIOINFO.fields_by_name['liquidity_ratio']._options = None
    _LIQUIDITYRATIOINFO.fields_by_name[
        'liquidity_ratio'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _LIQUIDITYRATIOINFO.fields_by_name['upper_band']._options = None
    _LIQUIDITYRATIOINFO.fields_by_name[
        'upper_band'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _LIQUIDITYRATIOINFO.fields_by_name['lower_band']._options = None
    _LIQUIDITYRATIOINFO.fields_by_name[
        'lower_band'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _QUERYLIQUIDITYRATIOINFORESPONSE.fields_by_name['info']._options = None
    _QUERYLIQUIDITYRATIOINFORESPONSE.fields_by_name['info']._serialized_options = b'\310\336\037\000'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\033\022\031/nibiru/stablecoin/params'
    _QUERY.methods_by_name['ModuleAccountBalances']._options = None
    _QUERY.methods_by_name[
        'ModuleAccountBalances'
    ]._serialized_options = b'\202\323\344\223\002+\022)/nibiru/stablecoin/module_account_balance'
    _QUERY.methods_by_name['CirculatingSupplies']._options = None
    _QUERY.methods_by_name[
        'CirculatingSupplies'
    ]._serialized_options = b'\202\323\344\223\002)\022\'/nibiru/stablecoin/circulating_supplies'
    _QUERY.methods_by_name['LiquidityRatioInfo']._options = None
    _QUERY.methods_by_name[
        'LiquidityRatioInfo'
    ]._serialized_options = b'\202\323\344\223\002)\022\'/nibiru/stablecoin/liquidity_ratio_info'
    _QUERYPARAMSREQUEST._serialized_start = 201
    _QUERYPARAMSREQUEST._serialized_end = 221
    _QUERYPARAMSRESPONSE._serialized_start = 223
    _QUERYPARAMSRESPONSE._serialized_end = 296
    _QUERYMODULEACCOUNTBALANCES._serialized_start = 298
    _QUERYMODULEACCOUNTBALANCES._serialized_end = 326
    _QUERYMODULEACCOUNTBALANCESRESPONSE._serialized_start = 329
    _QUERYMODULEACCOUNTBALANCESRESPONSE._serialized_end = 491
    _QUERYCIRCULATINGSUPPLIES._serialized_start = 493
    _QUERYCIRCULATINGSUPPLIES._serialized_end = 519
    _QUERYCIRCULATINGSUPPLIESRESPONSE._serialized_start = 522
    _QUERYCIRCULATINGSUPPLIESRESPONSE._serialized_end = 650
    _QUERYGOVTOMINTSTABLE._serialized_start = 652
    _QUERYGOVTOMINTSTABLE._serialized_end = 727
    _QUERYGOVTOMINTSTABLERESPONSE._serialized_start = 729
    _QUERYGOVTOMINTSTABLERESPONSE._serialized_end = 805
    _LIQUIDITYRATIOINFO._serialized_start = 808
    _LIQUIDITYRATIOINFO._serialized_end = 1037
    _QUERYLIQUIDITYRATIOINFOREQUEST._serialized_start = 1039
    _QUERYLIQUIDITYRATIOINFOREQUEST._serialized_end = 1071
    _QUERYLIQUIDITYRATIOINFORESPONSE._serialized_start = 1073
    _QUERYLIQUIDITYRATIOINFORESPONSE._serialized_end = 1168
    _QUERY._serialized_start = 1171
    _QUERY._serialized_end = 1852
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lockup/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from lockup.v1 import lock_pb2 as lockup_dot_v1_dot_lock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15lockup/v1/query.proto\x12\x10nibiru.lockup.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14lockup/v1/lock.proto\"*\n\x17QueryLockedCoinsRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"}\n\x18QueryLockedCoinsResponse\x12\x61\n\x0clocked_coins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x1e\n\x10QueryLockRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"9\n\x11QueryLockResponse\x12$\n\x04lock\x18\x01 \x01(\x0b\x32\x16.nibiru.lockup.v1.Lock\"b\n\x13QueryLocksByAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x81\x01\n\x1bQueryLocksByAddressResponse\x12%\n\x05locks\x18\x01 \x03(\x0b\x32\x16.nibiru.lockup.v1.Lock\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x93\x03\n\x05Query\x12\x89\x01\n\x0bLockedCoins\x12).nibiru.lockup.v1.QueryLockedCoinsRequest\x1a*.nibiru.lockup.v1.QueryLockedCoinsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/nibiru/lockup/locked_coins\x12l\n\x04Lock\x12\".nibiru.lockup.v1.QueryLockRequest\x1a#.nibiru.lockup.v1.QueryLockResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/nibiru/lockup/lock\x12\x8f\x01\n\x0eLocksByAddress\x12%.nibiru.lockup.v1.QueryLocksByAddress\x1a-.nibiru.lockup.v1.QueryLocksByAddressResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/nibiru/lockup/locks_by_addressB.Z,github.com/NibiruChain/nibiru/x/lockup/typesb\x06proto3')



_QUERYLOCKEDCOINSREQUEST = DESCRIPTOR.message_types_by_name['QueryLockedCoinsRequest']
_QUERYLOCKEDCOINSRESPONSE = DESCRIPTOR.message_types_by_name['QueryLockedCoinsResponse']
_QUERYLOCKREQUEST = DESCRIPTOR.message_types_by_name['QueryLockRequest']
_QUERYLOCKRESPONSE = DESCRIPTOR.message_types_by_name['QueryLockResponse']
_QUERYLOCKSBYADDRESS = DESCRIPTOR.message_types_by_name['QueryLocksByAddress']
_QUERYLOCKSBYADDRESSRESPONSE = DESCRIPTOR.message_types_by_name['QueryLocksByAddressResponse']
QueryLockedCoinsRequest = _reflection.GeneratedProtocolMessageType('QueryLockedCoinsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLOCKEDCOINSREQUEST,
  '__module__' : 'lockup.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.QueryLockedCoinsRequest)
  })
_sym_db.RegisterMessage(QueryLockedCoinsRequest)

QueryLockedCoinsResponse = _reflection.GeneratedProtocolMessageType('QueryLockedCoinsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLOCKEDCOINSRESPONSE,
  '__module__' : 'lockup.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.QueryLockedCoinsResponse)
  })
_sym_db.RegisterMessage(QueryLockedCoinsResponse)

QueryLockRequest = _reflection.GeneratedProtocolMessageType('QueryLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLOCKREQUEST,
  '__module__' : 'lockup.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.QueryLockRequest)
  })
_sym_db.RegisterMessage(QueryLockRequest)

QueryLockResponse = _reflection.GeneratedProtocolMessageType('QueryLockResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLOCKRESPONSE,
  '__module__' : 'lockup.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.QueryLockResponse)
  })
_sym_db.RegisterMessage(QueryLockResponse)

QueryLocksByAddress = _reflection.GeneratedProtocolMessageType('QueryLocksByAddress', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLOCKSBYADDRESS,
  '__module__' : 'lockup.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.QueryLocksByAddress)
  })
_sym_db.RegisterMessage(QueryLocksByAddress)

QueryLocksByAddressResponse = _reflection.GeneratedProtocolMessageType('QueryLocksByAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLOCKSBYADDRESSRESPONSE,
  '__module__' : 'lockup.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.QueryLocksByAddressResponse)
  })
_sym_db.RegisterMessage(QueryLocksByAddressResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/lockup/types'
  _QUERYLOCKEDCOINSRESPONSE.fields_by_name['locked_coins']._options = None
  _QUERYLOCKEDCOINSRESPONSE.fields_by_name['locked_coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERY.methods_by_name['LockedCoins']._options = None
  _QUERY.methods_by_name['LockedCoins']._serialized_options = b'\202\323\344\223\002\035\022\033/nibiru/lockup/locked_coins'
  _QUERY.methods_by_name['Lock']._options = None
  _QUERY.methods_by_name['Lock']._serialized_options = b'\202\323\344\223\002\025\022\023/nibiru/lockup/lock'
  _QUERY.methods_by_name['LocksByAddress']._options = None
  _QUERY.methods_by_name['LocksByAddress']._serialized_options = b'\202\323\344\223\002!\022\037/nibiru/lockup/locks_by_address'
  _QUERYLOCKEDCOINSREQUEST._serialized_start=193
  _QUERYLOCKEDCOINSREQUEST._serialized_end=235
  _QUERYLOCKEDCOINSRESPONSE._serialized_start=237
  _QUERYLOCKEDCOINSRESPONSE._serialized_end=362
  _QUERYLOCKREQUEST._serialized_start=364
  _QUERYLOCKREQUEST._serialized_end=394
  _QUERYLOCKRESPONSE._serialized_start=396
  _QUERYLOCKRESPONSE._serialized_end=453
  _QUERYLOCKSBYADDRESS._serialized_start=455
  _QUERYLOCKSBYADDRESS._serialized_end=553
  _QUERYLOCKSBYADDRESSRESPONSE._serialized_start=556
  _QUERYLOCKSBYADDRESSRESPONSE._serialized_end=685
  _QUERY._serialized_start=688
  _QUERY._serialized_end=1091
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos_proto/cosmos.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmos_proto/cosmos.proto\x12\x0c\x63osmos_proto\x1a google/protobuf/descriptor.proto:9\n\x0einterface_type\x12\x1f.google.protobuf.MessageOptions\x18\xc9\xd6\x05 \x01(\t:?\n\x14implements_interface\x12\x1f.google.protobuf.MessageOptions\x18\xca\xd6\x05 \x01(\t::\n\x11\x61\x63\x63\x65pts_interface\x12\x1d.google.protobuf.FieldOptions\x18\xc9\xd6\x05 \x01(\tB\'Z%github.com/regen-network/cosmos-protob\x06proto3')


INTERFACE_TYPE_FIELD_NUMBER = 93001
interface_type = DESCRIPTOR.extensions_by_name['interface_type']
IMPLEMENTS_INTERFACE_FIELD_NUMBER = 93002
implements_interface = DESCRIPTOR.extensions_by_name['implements_interface']
ACCEPTS_INTERFACE_FIELD_NUMBER = 93001
accepts_interface = DESCRIPTOR.extensions_by_name['accepts_interface']

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(interface_type)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(implements_interface)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(accepts_interface)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z%github.com/regen-network/cosmos-proto'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pricefeed import params_pb2 as pricefeed_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15pricefeed/query.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16pricefeed/params.proto\"\x14\n\x12QueryParamsRequest\"N\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.nibiru.pricefeed.v1.ParamsB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"*\n\x11QueryPriceRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t:\x04\x88\xa0\x1f\x00\"Z\n\x12QueryPriceResponse\x12>\n\x05price\x18\x01 \x01(\x0b\x32).nibiru.pricefeed.v1.CurrentPriceResponseB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x14\n\x12QueryPricesRequest\"u\n\x13QueryPricesResponse\x12X\n\x06prices\x18\x01 \x03(\x0b\x32).nibiru.pricefeed.v1.CurrentPriceResponseB\x1d\xaa\xdf\x1f\x15\x43urrentPriceResponses\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\".\n\x15QueryRawPricesRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t:\x04\x88\xa0\x1f\x00\"z\n\x16QueryRawPricesResponse\x12Z\n\nraw_prices\x18\x01 \x03(\x0b\x32(.nibiru.pricefeed.v1.PostedPriceResponseB\x1c\xaa\xdf\x1f\x14PostedPriceResponses\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\",\n\x13QueryOraclesRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t:\x04\x88\xa0\x1f\x00\"-\n\x14QueryOraclesResponse\x12\x0f\n\x07oracles\x18\x01 \x03(\t:\x04\x88\xa0\x1f\x00\"\x15\n\x13QueryMarketsRequest\"[\n\x14QueryMarketsResponse\x12=\n\x07markets\x18\x01 \x03(\x0b\x32\x1b.nibiru.pricefeed.v1.MarketB\x0f\xaa\xdf\x1f\x07Markets\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\xbf\x01\n\x13PostedPriceResponse\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x16\n\x0eoracle_address\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"r\n\x14\x43urrentPriceResponse\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"F\n\x06Market\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x0f\n\x07oracles\x18\x02 \x03(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x32\x84\x07\n\x05Query\x12\x8a\x01\n\x0bQueryParams\x12\'.nibiru.pricefeed.v1.QueryParamsRequest\x1a(.nibiru.pricefeed.v1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /nibiru/pricefeed/v1beta1/params\x12\x91\x01\n\nQueryPrice\x12&.nibiru.pricefeed.v1.QueryPriceRequest\x1a\'.nibiru.pricefeed.v1.QueryPriceResponse\"2\x82\xd3\xe4\x93\x02,\x12*/nibiru/pricefeed/v1beta1/prices/{pair_id}\x12\x8a\x01\n\x0bQueryPrices\x12\'.nibiru.pricefeed.v1.QueryPricesRequest\x1a(.nibiru.pricefeed.v1.QueryPricesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /nibiru/pricefeed/v1beta1/prices\x12\xa0\x01\n\x0eQueryRawPrices\x12*.nibiru.pricefeed.v1.QueryRawPricesRequest\x1a+.nibiru.pricefeed.v1.QueryRawPricesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/nibiru/pricefeed/v1beta1/rawprices/{pair_id}\x12\x98\x01\n\x0cQueryOracles\x12(.nibiru.pricefeed.v1.QueryOraclesRequest\x1a).nibiru.pricefeed.v1.QueryOraclesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/nibiru/pricefeed/v1beta1/oracles/{pair_id}\x12\x8e\x01\n\x0cQueryMarkets\x12(.nibiru.pricefeed.v1.QueryMarketsRequest\x1a).nibiru.pricefeed.v1.QueryMarketsResponse\")\x82\xd3\xe4\x93\x02#\x12!/nibiru/pricefeed/v1beta1/marketsB9Z/github.com/NibiruChain/nibiru/x/pricefeed/types\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\x62\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYPRICEREQUEST = DESCRIPTOR.message_types_by_name['QueryPriceRequest']
_QUERYPRICERESPONSE = DESCRIPTOR.message_types_by_name['QueryPriceResponse']
_QUERYPRICESREQUEST = DESCRIPTOR.message_types_by_name['QueryPricesRequest']
_QUERYPRICESRESPONSE = DESCRIPTOR.message_types_by_name['QueryPricesResponse']
_QUERYRAWPRICESREQUEST = DESCRIPTOR.message_types_by_name['QueryRawPricesRequest']
_QUERYRAWPRICESRESPONSE = DESCRIPTOR.message_types_by_name['QueryRawPricesResponse']
_QUERYORACLESREQUEST = DESCRIPTOR.message_types_by_name['QueryOraclesRequest']
_QUERYORACLESRESPONSE = DESCRIPTOR.message_types_by_name['QueryOraclesResponse']
_QUERYMARKETSREQUEST = DESCRIPTOR.message_types_by_name['QueryMarketsRequest']
_QUERYMARKETSRESPONSE = DESCRIPTOR.message_types_by_name['QueryMarketsResponse']
_POSTEDPRICERESPONSE = DESCRIPTOR.message_types_by_name['PostedPriceResponse']
_CURRENTPRICERESPONSE = DESCRIPTOR.message_types_by_name['CurrentPriceResponse']
_MARKET = DESCRIPTOR.message_types_by_name['Market']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryPriceRequest = _reflection.GeneratedProtocolMessageType('QueryPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICEREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPriceRequest)
  })
_sym_db.RegisterMessage(QueryPriceRequest)

QueryPriceResponse = _reflection.GeneratedProtocolMessageType('QueryPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICERESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPriceResponse)
  })
_sym_db.RegisterMessage(QueryPriceResponse)

QueryPricesRequest = _reflection.GeneratedProtocolMessageType('QueryPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICESREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPricesRequest)
  })
_sym_db.RegisterMessage(QueryPricesRequest)

QueryPricesResponse = _reflection.GeneratedProtocolMessageType('QueryPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPRICESRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryPricesResponse)
  })
_sym_db.RegisterMessage(QueryPricesResponse)

QueryRawPricesRequest = _reflection.GeneratedProtocolMessageType('QueryRawPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWPRICESREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryRawPricesRequest)
  })
_sym_db.RegisterMessage(QueryRawPricesRequest)

QueryRawPricesResponse = _reflection.GeneratedProtocolMessageType('QueryRawPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWPRICESRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryRawPricesResponse)
  })
_sym_db.RegisterMessage(QueryRawPricesResponse)

QueryOraclesRequest = _reflection.GeneratedProtocolMessageType('QueryOraclesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryOraclesRequest)
  })
_sym_db.RegisterMessage(QueryOraclesRequest)

QueryOraclesResponse = _reflection.GeneratedProtocolMessageType('QueryOraclesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYORACLESRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryOraclesResponse)
  })
_sym_db.RegisterMessage(QueryOraclesResponse)

QueryMarketsRequest = _reflection.GeneratedProtocolMessageType('QueryMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETSREQUEST,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryMarketsRequest)
  })
_sym_db.RegisterMessage(QueryMarketsRequest)

QueryMarketsResponse = _reflection.GeneratedProtocolMessageType('QueryMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETSRESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.QueryMarketsResponse)
  })
_sym_db.RegisterMessage(QueryMarketsResponse)

PostedPriceResponse = _reflection.GeneratedProtocolMessageType('PostedPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTEDPRICERESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.PostedPriceResponse)
  })
_sym_db.RegisterMessage(PostedPriceResponse)

CurrentPriceResponse = _reflection.GeneratedProtocolMessageType('CurrentPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTPRICERESPONSE,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.CurrentPriceResponse)
  })
_sym_db.RegisterMessage(CurrentPriceResponse)

Market = _reflection.GeneratedProtocolMessageType('Market', (_message.Message,), {
  'DESCRIPTOR' : _MARKET,
  '__module__' : 'pricefeed.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.Market)
  })
_sym_db.RegisterMessage(Market)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types\250\342\036\001\340\341\036\001'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE._options = None
  _QUERYPARAMSRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYPRICEREQUEST._options = None
  _QUERYPRICEREQUEST._serialized_options = b'\210\240\037\000'
  _QUERYPRICERESPONSE.fields_by_name['price']._options = None
  _QUERYPRICERESPONSE.fields_by_name['price']._serialized_options = b'\310\336\037\000'
  _QUERYPRICERESPONSE._options = None
  _QUERYPRICERESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYPRICESRESPONSE.fields_by_name['prices']._options = None
  _QUERYPRICESRESPONSE.fields_by_name['prices']._serialized_options = b'\252\337\037\025CurrentPriceResponses\310\336\037\000'
  _QUERYPRICESRESPONSE._options = None
  _QUERYPRICESRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYRAWPRICESREQUEST._options = None
  _QUERYRAWPRICESREQUEST._serialized_options = b'\210\240\037\000'
  _QUERYRAWPRICESRESPONSE.fields_by_name['raw_prices']._options = None
  _QUERYRAWPRICESRESPONSE.fields_by_name['raw_prices']._serialized_options = b'\252\337\037\024PostedPriceResponses\310\336\037\000'
  _QUERYRAWPRICESRESPONSE._options = None
  _QUERYRAWPRICESRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYORACLESREQUEST._options = None
  _QUERYORACLESREQUEST._serialized_options = b'\210\240\037\000'
  _QUERYORACLESRESPONSE._options = None
  _QUERYORACLESRESPONSE._serialized_options = b'\210\240\037\000'
  _QUERYMARKETSRESPONSE.fields_by_name['markets']._options = None
  _QUERYMARKETSRESPONSE.fields_by_name['markets']._serialized_options = b'\252\337\037\007Markets\310\336\037\000'
  _QUERYMARKETSRESPONSE._options = None
  _QUERYMARKETSRESPONSE._serialized_options = b'\210\240\037\000'
  _POSTEDPRICERESPONSE.fields_by_name['pair_id']._options = None
  _POSTEDPRICERESPONSE.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _POSTEDPRICERESPONSE.fields_by_name['price']._options = None
  _POSTEDPRICERESPONSE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSTEDPRICERESPONSE.fields_by_name['expiry']._options = None
  _POSTEDPRICERESPONSE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _CURRENTPRICERESPONSE.fields_by_name['pair_id']._options = None
  _CURRENTPRICERESPONSE.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _CURRENTPRICERESPONSE.fields_by_name['price']._options = None
  _CURRENTPRICERESPONSE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKET.fields_by_name['pair_id']._options = None
  _MARKET.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _QUERY.methods_by_name['QueryParams']._options = None
  _QUERY.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\"\022 /nibiru/pricefeed/v1beta1/params'
  _QUERY.methods_by_name['QueryPrice']._options = None
  _QUERY.methods_by_name['QueryPrice']._serialized_options = b'\202\323\344\223\002,\022*/nibiru/pricefeed/v1beta1/prices/{pair_id}'
  _QUERY.methods_by_name['QueryPrices']._options = None
  _QUERY.methods_by_name['QueryPrices']._serialized_options = b'\202\323\344\223\002\"\022 /nibiru/pricefeed/v1beta1/prices'
  _QUERY.methods_by_name['QueryRawPrices']._options = None
  _QUERY.methods_by_name['QueryRawPrices']._serialized_options = b'\202\323\344\223\002/\022-/nibiru/pricefeed/v1beta1/rawprices/{pair_id}'
  _QUERY.methods_by_name['QueryOracles']._options = None
  _QUERY.methods_by_name['QueryOracles']._serialized_options = b'\202\323\344\223\002-\022+/nibiru/pricefeed/v1beta1/oracles/{pair_id}'
  _QUERY.methods_by_name['QueryMarkets']._options = None
  _QUERY.methods_by_name['QueryMarkets']._serialized_options = b'\202\323\344\223\002#\022!/nibiru/pricefeed/v1beta1/markets'
  _QUERYPARAMSREQUEST._serialized_start=155
  _QUERYPARAMSREQUEST._serialized_end=175
  _QUERYPARAMSRESPONSE._serialized_start=177
  _QUERYPARAMSRESPONSE._serialized_end=255
  _QUERYPRICEREQUEST._serialized_start=257
  _QUERYPRICEREQUEST._serialized_end=299
  _QUERYPRICERESPONSE._serialized_start=301
  _QUERYPRICERESPONSE._serialized_end=391
  _QUERYPRICESREQUEST._serialized_start=393
  _QUERYPRICESREQUEST._serialized_end=413
  _QUERYPRICESRESPONSE._serialized_start=415
  _QUERYPRICESRESPONSE._serialized_end=532
  _QUERYRAWPRICESREQUEST._serialized_start=534
  _QUERYRAWPRICESREQUEST._serialized_end=580
  _QUERYRAWPRICESRESPONSE._serialized_start=582
  _QUERYRAWPRICESRESPONSE._serialized_end=704
  _QUERYORACLESREQUEST._serialized_start=706
  _QUERYORACLESREQUEST._serialized_end=750
  _QUERYORACLESRESPONSE._serialized_start=752
  _QUERYORACLESRESPONSE._serialized_end=797
  _QUERYMARKETSREQUEST._serialized_start=799
  _QUERYMARKETSREQUEST._serialized_end=820
  _QUERYMARKETSRESPONSE._serialized_start=822
  _QUERYMARKETSRESPONSE._serialized_end=913
  _POSTEDPRICERESPONSE._serialized_start=916
  _POSTEDPRICERESPONSE._serialized_end=1107
  _CURRENTPRICERESPONSE._serialized_start=1109
  _CURRENTPRICERESPONSE._serialized_end=1223
  _MARKET._serialized_start=1225
  _MARKET._serialized_end=1295
  _QUERY._serialized_start=1298
  _QUERY._serialized_end=2198
# @@protoc_insertion_point(module_scope)



from .client import Client  # noqa
from .common import Direction, PoolAsset, Side, TxConfig  # noqa
from .composer import Composer  # noqa
from .network import Network  # noqa
from .sdk import Sdk  # noqa
from .transaction import Transaction  # noqa
from .wallet import Address, PrivateKey, PublicKey  # noqa



from nibiru.common import Side
from nibiru.composers import Perp as PerpComposer
from nibiru.proto.cosmos.base.v1beta1 import coin_pb2 as coin_pb

from .common import Tx


class Perp(Tx):
    def remove_margin(self, sender: str, token_pair: str, margin: coin_pb.Coin, **kwargs):
        msg = PerpComposer.remove_margin(sender=sender, token_pair=token_pair, margin=margin)
        return super().execute_msg(msg, **kwargs)

    def add_margin(self, sender: str, token_pair: str, margin: coin_pb.Coin, **kwargs):
        msg = PerpComposer.add_margin(sender=sender, token_pair=token_pair, margin=margin)
        return super().execute_msg(msg, **kwargs)

    def liquidate(self, sender: str, token_pair: str, trader: str, **kwargs):
        msg = PerpComposer.liquidate(sender=sender, token_pair=token_pair, trader=trader)
        return super().execute_msg(msg, **kwargs)

    def open_position(
        self,
        sender: str,
        token_pair: str,
        side: Side,
        quote_asset_amount: str,
        leverage: str,
        base_asset_amount_limit: str,
        **kwargs,
    ):
        msg = PerpComposer.open_position(
            sender=sender,
            token_pair=token_pair,
            side=side,
            quote_asset_amount=quote_asset_amount,
            leverage=leverage,
            base_asset_amount_limit=base_asset_amount_limit,
        )
        return super().execute_msg(msg, **kwargs)

    def close_position(self, sender: str, token_pair: str, **kwargs):
        msg = PerpComposer.close_position(
            sender=sender,
            token_pair=token_pair,
        )
        return super().execute_msg(msg, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pricefeed import params_pb2 as pricefeed_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17pricefeed/genesis.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x16pricefeed/params.proto\"\xa9\x01\n\x0cGenesisState\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.nibiru.pricefeed.v1.ParamsB\x04\xc8\xde\x1f\x00\x12M\n\rposted_prices\x18\x02 \x03(\x0b\x32 .nibiru.pricefeed.v1.PostedPriceB\x14\xaa\xdf\x1f\x0cPostedPrices\xc8\xde\x1f\x00\x12\x17\n\x0fgenesis_oracles\x18\x03 \x03(\tB1Z/github.com/NibiruChain/nibiru/x/pricefeed/typesb\x06proto3')



_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'pricefeed.genesis_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['posted_prices']._options = None
  _GENESISSTATE.fields_by_name['posted_prices']._serialized_options = b'\252\337\037\014PostedPrices\310\336\037\000'
  _GENESISSTATE._serialized_start=95
  _GENESISSTATE._serialized_end=264
# @@protoc_insertion_point(module_scope)



import logging

from .client import Client
from .common import TxConfig
from .network import Network
from .sdks.tx import TxClient
from .wallet import PrivateKey


class Sdk:
    def __init__(self, _error_do_not_use_init_directly=None) -> None:
        """Unsupported, please use from_mnemonic to initialize."""
        if not _error_do_not_use_init_directly:
            raise TypeError("Please use PrivateKey.from_mnemonic() to construct me")
        self._priv_key: PrivateKey = None
        self.query = None
        self.tx = None
        self._network = None
        self.config = TxConfig()

    @classmethod
    def authorize(cls, key: str = "") -> "Sdk":
        self = cls(_error_do_not_use_init_directly=True)
        if key == "":
            (mnemonic, pk) = PrivateKey.generate()
            logging.warning("The mnemonic used for the newly generated key is: \n%s", mnemonic)
            logging.warning("Please write down this key, it will NOT be recoverable otherwise")
        if len(key.split(" ")) > 1:
            pk = PrivateKey.from_mnemonic(key)
        elif len(key) > 0:
            pk = PrivateKey.from_hex(key)

        self.with_priv_key(pk)

        return self

    def with_network(self, network: Network) -> "Sdk":
        self._network = network
        self.with_query_client(Client(self._network, True))
        return self

    def with_query_client(self, client: Client) -> "Sdk":
        self.query = client
        tx_client = TxClient(client=self.query, network=self._network, priv_key=self._priv_key, config=self.config)
        self.with_tx_client(tx_client)
        return self

    def with_tx_client(self, client: TxClient) -> "Sdk":
        self.tx = client
        return self

    def with_priv_key(self, priv_key: PrivateKey) -> "Sdk":
        self._priv_key = priv_key
        self.with_network(Network.local())
        return self

    def with_config(self, config: TxConfig) -> "Sdk":
        self.config = config
        tx_client = TxClient(client=self.query, network=self._network, priv_key=self._priv_key, config=self.config)
        self.with_tx_client(tx_client)
        return self

    @property
    def address(self):
        pub_key = self._priv_key.to_public_key()
        return pub_key.to_address().to_acc_bech32()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epochs/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65pochs/genesis.proto\x12\x15nibiru.epochs.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x03\n\tEpochInfo\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12M\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1d\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x11yaml:\"start_time\"\x12^\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12\x15\n\rcurrent_epoch\x18\x04 \x01(\x03\x12i\n\x18\x63urrent_epoch_start_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB+\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:\"current_epoch_start_time\"\x12\x1e\n\x16\x65poch_counting_started\x18\x06 \x01(\x08\x12\"\n\x1a\x63urrent_epoch_start_height\x18\x07 \x01(\x03\"F\n\x0cGenesisState\x12\x36\n\x06\x65pochs\x18\x01 \x03(\x0b\x32 .nibiru.epochs.v1beta1.EpochInfoB\x04\xc8\xde\x1f\x00\x42.Z,github.com/NibiruChain/nibiru/x/epochs/typesb\x06proto3')



_EPOCHINFO = DESCRIPTOR.message_types_by_name['EpochInfo']
_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
EpochInfo = _reflection.GeneratedProtocolMessageType('EpochInfo', (_message.Message,), {
  'DESCRIPTOR' : _EPOCHINFO,
  '__module__' : 'epochs.genesis_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.epochs.v1beta1.EpochInfo)
  })
_sym_db.RegisterMessage(EpochInfo)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'epochs.genesis_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.epochs.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/epochs/types'
  _EPOCHINFO.fields_by_name['start_time']._options = None
  _EPOCHINFO.fields_by_name['start_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\021yaml:\"start_time\"'
  _EPOCHINFO.fields_by_name['duration']._options = None
  _EPOCHINFO.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _EPOCHINFO.fields_by_name['current_epoch_start_time']._options = None
  _EPOCHINFO.fields_by_name['current_epoch_start_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\037yaml:\"current_epoch_start_time\"'
  _GENESISSTATE.fields_by_name['epochs']._options = None
  _GENESISSTATE.fields_by_name['epochs']._serialized_options = b'\310\336\037\000'
  _EPOCHINFO._serialized_start=135
  _EPOCHINFO._serialized_end=539
  _GENESISSTATE._serialized_start=541
  _GENESISSTATE._serialized_end=611
# @@protoc_insertion_point(module_scope)



import datetime
import logging
import time
from http.cookies import SimpleCookie
from typing import List, Optional, Tuple, Union

import grpc

from .clients import Dex as DexClient
from .clients import Perp as PerpClient
from .clients import VPool as VPoolClient
from .exceptions import NotFoundError
from .network import Network
from .proto.cosmos.auth.v1beta1 import auth_pb2 as auth_type
from .proto.cosmos.auth.v1beta1 import query_pb2 as auth_query
from .proto.cosmos.auth.v1beta1 import query_pb2_grpc as auth_query_grpc
from .proto.cosmos.authz.v1beta1 import query_pb2 as authz_query
from .proto.cosmos.authz.v1beta1 import query_pb2_grpc as authz_query_grpc
from .proto.cosmos.bank.v1beta1 import query_pb2 as bank_query
from .proto.cosmos.bank.v1beta1 import query_pb2_grpc as bank_query_grpc
from .proto.cosmos.base.abci.v1beta1 import abci_pb2 as abci_type
from .proto.cosmos.base.tendermint.v1beta1 import query_pb2 as tendermint_query
from .proto.cosmos.base.tendermint.v1beta1 import (
    query_pb2_grpc as tendermint_query_grpc,
)
from .proto.cosmos.tx.v1beta1 import service_pb2 as tx_service
from .proto.cosmos.tx.v1beta1 import service_pb2_grpc as tx_service_grpc
from .proto.epochs import query_pb2_grpc as epochs_query
from .proto.incentivization.v1 import incentivization_pb2_grpc as incentivization_query
from .proto.lockup.v1 import query_pb2_grpc as lockup_query
from .proto.pricefeed import query_pb2_grpc as pricefeed_query
from .proto.stablecoin import query_pb2_grpc as stablecoin_query

DEFAULT_TIMEOUTHEIGHT_SYNC_INTERVAL = 10  # seconds
DEFAULT_TIMEOUTHEIGHT = 20  # blocks
DEFAULT_SESSION_RENEWAL_OFFSET = 120  # seconds
DEFAULT_BLOCK_TIME = 3  # seconds
DEFAULT_CHAIN_COOKIE_NAME = '.chain_cookie'

# use append mode to create file if not exist
cookie_file = open(DEFAULT_CHAIN_COOKIE_NAME, "a+")
cookie_file.close()


class Client:
    def __init__(
        self,
        network: Network,
        insecure: bool = False,
        credentials: grpc.ChannelCredentials = None,
    ):

        # load root CA cert
        # if not insecure:
        #     if network.env == 'testnet':
        #         if credentials is None:
        #             with open(os.path.join(os.path.dirname(__file__), 'cert/testnet.crt'), 'rb') as f:
        #                 credentials = grpc.ssl_channel_credentials(f.read())
        #     if network.env == 'mainnet':
        #         if credentials is None:
        #             with open(os.path.join(os.path.dirname(__file__), 'cert/mainnet.crt'), 'rb') as f:
        #                 credentials = grpc.ssl_channel_credentials(f.read())

        # chain stubs
        self.chain_channel = (
            grpc.insecure_channel(network.grpc_endpoint)
            if insecure
            else grpc.secure_channel(network.grpc_endpoint, credentials)
        )
        self.insecure = insecure
        self.stubCosmosTendermint = tendermint_query_grpc.ServiceStub(self.chain_channel)
        self.stubAuth = auth_query_grpc.QueryStub(self.chain_channel)
        self.stubAuthz = authz_query_grpc.QueryStub(self.chain_channel)
        self.stubBank = bank_query_grpc.QueryStub(self.chain_channel)
        self.stubTx = tx_service_grpc.ServiceStub(self.chain_channel)

        # attempt to load from disk
        cookie_file = open(DEFAULT_CHAIN_COOKIE_NAME, "r+")
        self.chain_cookie = cookie_file.read()
        cookie_file.close()
        logging.info("chain session cookie loaded from disk: %s", self.chain_cookie)

        self.exchange_cookie = ""
        self.timeout_height = 1

        # exchange stubs
        self.exchange_channel = (
            grpc.insecure_channel(network.grpc_exchange_endpoint)
            if insecure
            else grpc.secure_channel(network.grpc_exchange_endpoint, credentials)
        )
        # Query services
        self.dex = DexClient(self.exchange_channel)
        self.stubPricefeed = pricefeed_query.QueryStub(self.exchange_channel)
        self.perp = PerpClient(self.exchange_channel)
        self.stubLockup = lockup_query.QueryStub(self.exchange_channel)
        self.stubIncentivization = incentivization_query.QueryStub(self.exchange_channel)
        self.vpool = VPoolClient(self.exchange_channel)
        self.stubStablecoin = stablecoin_query.QueryStub(self.exchange_channel)
        self.stubEpochs = epochs_query.QueryStub(self.exchange_channel)

        # timeout height update routine
        # aiocron.crontab(
        #     '* * * * * */{}'.format(DEFAULT_TIMEOUTHEIGHT_SYNC_INTERVAL),
        #     func=self.sync_timeout_height,
        #     args=(),
        #     start=True
        # )

    def close_exchange_channel(self):
        self.exchange_channel.close()

    def close_chain_channel(self):
        self.chain_channel.close()

    def sync_timeout_height(self):
        block = self.get_latest_block()
        self.timeout_height = block.block.header.height + DEFAULT_TIMEOUTHEIGHT

    # cookie helper methods
    def fetch_cookie(self, chain_type):
        metadata = None
        if chain_type == "chain":
            req = tendermint_query.GetLatestBlockRequest()
            metadata = self.stubCosmosTendermint.GetLatestBlock(req).initial_metadata()
            time.sleep(DEFAULT_BLOCK_TIME)
        # if chain_type == "exchange":
        # not sure what to do here, do we have a counterpart or can any req/resp be used??
        # req = exchange_meta_rpc_pb.VersionRequest()
        # metadata = self.stubMeta.Version(req).initial_metadata()
        return metadata

    def renew_cookie(self, existing_cookie, chain_type):
        metadata = None
        # format cookie date into RFC1123 standard
        cookie = SimpleCookie()
        cookie.load(existing_cookie)
        expires_at = cookie.get("grpc-cookie").get("expires")
        expires_at = expires_at.replace("-", " ")
        yyyy = "20{}".format(expires_at[12:14])
        expires_at = expires_at[:12] + yyyy + expires_at[14:]

        # parse expire field to unix timestamp
        expire_timestamp = datetime.datetime.strptime(expires_at, "%a, %d %b %Y %H:%M:%S GMT").timestamp()

        # renew session if timestamp diff < offset
        timestamp_diff = expire_timestamp - int(time.time())
        if timestamp_diff < DEFAULT_SESSION_RENEWAL_OFFSET:
            metadata = self.fetch_cookie(chain_type)
        else:
            metadata = (("cookie", existing_cookie),)
        return metadata

    def load_cookie(self, chain_type):
        metadata = None
        if self.insecure:
            return metadata

        if chain_type == "chain":
            if self.chain_cookie != "":
                metadata = self.renew_cookie(self.chain_cookie, chain_type)
                self.set_cookie(metadata, chain_type)
            else:
                metadata = self.fetch_cookie(chain_type)
                self.set_cookie(metadata, chain_type)

        if chain_type == "exchange":
            if self.exchange_cookie != "":
                metadata = self.renew_cookie(self.exchange_cookie, chain_type)
                self.set_cookie(metadata, chain_type)
            else:
                metadata = self.fetch_cookie(chain_type)
                self.set_cookie(metadata, chain_type)

        return metadata

    def set_cookie(self, metadata, chain_type):
        new_cookie = None
        if self.insecure:
            return new_cookie

        for k, v in metadata:
            if k == "set-cookie":
                new_cookie = v

        if new_cookie is None:
            return

        if chain_type == "chain":
            # write to client instance
            self.chain_cookie = new_cookie
            # write to disk
            cookie_file = open(DEFAULT_CHAIN_COOKIE_NAME, "w")
            cookie_file.write(new_cookie)
            cookie_file.close()
            logging.info("chain session cookie saved to disk")

        if chain_type == "exchange":
            self.exchange_cookie = new_cookie

    # default client methods
    def get_latest_block(self) -> tendermint_query.GetLatestBlockResponse:
        req = tendermint_query.GetLatestBlockRequest()
        return self.stubCosmosTendermint.GetLatestBlock(req)

    def get_account(self, address: str) -> Optional[auth_type.BaseAccount]:
        try:
            account_any = self.stubAuth.Account(auth_query.QueryAccountRequest(address=address)).account
            account = auth_type.BaseAccount()
            if account_any.Is(account.DESCRIPTOR):
                account_any.Unpack(account)
                return account
        except:
            return None

    def get_request_id_by_tx_hash(self, tx_hash: bytes) -> List[int]:
        tx = self.stubTx.GetTx(tx_service.GetTxRequest(hash=tx_hash))
        request_ids = []
        for tx in tx.tx_response.logs:
            request_event = [event for event in tx.events if event.type == "request" or event.type == "report"]
            if len(request_event) == 1:
                attrs = request_event[0].attributes
                attr_id = [attr for attr in attrs if attr.key == "id"]
                if len(attr_id) == 1:
                    request_id = attr_id[0].value
                    request_ids.append(int(request_id))
        if len(request_ids) == 0:
            raise NotFoundError("Request Id is not found")
        return request_ids

    def simulate_tx(self, tx_byte: bytes) -> Tuple[Union[abci_type.SimulationResponse, grpc.RpcError], bool]:
        try:
            req = tx_service.SimulateRequest(tx_bytes=tx_byte)
            metadata = self.load_cookie(chain_type="chain")
            return self.stubTx.Simulate.__call__(req, metadata=metadata), True
        except grpc.RpcError as err:
            return err, False

    def send_tx_sync_mode(self, tx_byte: bytes) -> abci_type.TxResponse:
        req = tx_service.BroadcastTxRequest(tx_bytes=tx_byte, mode=tx_service.BroadcastMode.BROADCAST_MODE_SYNC)
        metadata = self.load_cookie(chain_type="chain")
        result = self.stubTx.BroadcastTx.__call__(req, metadata=metadata)
        return result.tx_response

    def send_tx_async_mode(self, tx_byte: bytes) -> abci_type.TxResponse:
        req = tx_service.BroadcastTxRequest(tx_bytes=tx_byte, mode=tx_service.BroadcastMode.BROADCAST_MODE_ASYNC)
        metadata = self.load_cookie(chain_type="chain")
        result = self.stubTx.BroadcastTx.__call__(req, metadata=metadata)
        return result.tx_response

    def send_tx_block_mode(self, tx_byte: bytes) -> abci_type.TxResponse:
        req = tx_service.BroadcastTxRequest(tx_bytes=tx_byte, mode=tx_service.BroadcastMode.BROADCAST_MODE_BLOCK)
        metadata = self.load_cookie(chain_type="chain")
        result = self.stubTx.BroadcastTx.__call__(req, metadata=metadata)
        return result.tx_response

    def get_chain_id(self) -> str:
        latest_block = self.get_latest_block()
        return latest_block.block.header.chain_id

    def get_grants(self, granter: str, grantee: str, **kwargs):
        return self.stubAuthz.Grants(
            authz_query.QueryGrantsRequest(
                granter=granter,
                grantee=grantee,
                msg_type_url=kwargs.get("msg_type_url"),
            )
        )

    def get_bank_balances(self, address: str):
        return self.stubBank.AllBalances(bank_query.QueryAllBalancesRequest(address=address))

    def get_bank_balance(self, address: str, denom: str):
        return self.stubBank.Balance(bank_query.QueryBalanceRequest(address=address, denom=denom))



from grpc import Channel

from nibiru.proto.perp.v1 import query_pb2 as perp_type
from nibiru.proto.perp.v1 import query_pb2_grpc as perp_query

from .util import deserialize


class Perp:
    """
    Perp allows to query the endpoints made available by the Nibiru Chain's PERP module.
    """

    def __init__(self, channel: Channel):
        self.api = perp_query.QueryStub(channel)

    def params(self):
        req = perp_type.QueryParamsRequest()
        return deserialize(self.api.Params(req))

    def trader_position(self, token_pair: str, trader: str):
        req = perp_type.QueryTraderPositionRequest(
            token_pair=token_pair,
            trader=trader,
        )
        return deserialize(self.api.TraderPosition(req))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stablecoin/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17stablecoin/events.proto\x12\x14nibiru.stablecoin.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"X\n\rEventTransfer\x12-\n\x04\x63oin\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\n\n\x02to\x18\x03 \x01(\t\"Q\n\x0f\x45ventMintStable\x12>\n\x06\x61mount\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"Q\n\x0f\x45ventBurnStable\x12>\n\x06\x61mount\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"O\n\rEventMintNIBI\x12>\n\x06\x61mount\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"O\n\rEventBurnNIBI\x12>\n\x06\x61mount\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\xcf\x01\n\x14\x45ventRecollateralize\x12\x0e\n\x06\x63\x61ller\x18\x01 \x01(\t\x12\x30\n\x07in_coin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x31\n\x08out_coin\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x42\n\ncoll_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xc7\x01\n\x0c\x45ventBuyback\x12\x0e\n\x06\x63\x61ller\x18\x01 \x01(\t\x12\x30\n\x07in_coin\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x31\n\x08out_coin\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x42\n\ncoll_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x32Z0github.com/NibiruChain/nibiru/x/stablecoin/typesb\x06proto3')



_EVENTTRANSFER = DESCRIPTOR.message_types_by_name['EventTransfer']
_EVENTMINTSTABLE = DESCRIPTOR.message_types_by_name['EventMintStable']
_EVENTBURNSTABLE = DESCRIPTOR.message_types_by_name['EventBurnStable']
_EVENTMINTNIBI = DESCRIPTOR.message_types_by_name['EventMintNIBI']
_EVENTBURNNIBI = DESCRIPTOR.message_types_by_name['EventBurnNIBI']
_EVENTRECOLLATERALIZE = DESCRIPTOR.message_types_by_name['EventRecollateralize']
_EVENTBUYBACK = DESCRIPTOR.message_types_by_name['EventBuyback']
EventTransfer = _reflection.GeneratedProtocolMessageType('EventTransfer', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRANSFER,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventTransfer)
  })
_sym_db.RegisterMessage(EventTransfer)

EventMintStable = _reflection.GeneratedProtocolMessageType('EventMintStable', (_message.Message,), {
  'DESCRIPTOR' : _EVENTMINTSTABLE,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventMintStable)
  })
_sym_db.RegisterMessage(EventMintStable)

EventBurnStable = _reflection.GeneratedProtocolMessageType('EventBurnStable', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBURNSTABLE,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventBurnStable)
  })
_sym_db.RegisterMessage(EventBurnStable)

EventMintNIBI = _reflection.GeneratedProtocolMessageType('EventMintNIBI', (_message.Message,), {
  'DESCRIPTOR' : _EVENTMINTNIBI,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventMintNIBI)
  })
_sym_db.RegisterMessage(EventMintNIBI)

EventBurnNIBI = _reflection.GeneratedProtocolMessageType('EventBurnNIBI', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBURNNIBI,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventBurnNIBI)
  })
_sym_db.RegisterMessage(EventBurnNIBI)

EventRecollateralize = _reflection.GeneratedProtocolMessageType('EventRecollateralize', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRECOLLATERALIZE,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventRecollateralize)
  })
_sym_db.RegisterMessage(EventRecollateralize)

EventBuyback = _reflection.GeneratedProtocolMessageType('EventBuyback', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBUYBACK,
  '__module__' : 'stablecoin.events_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.EventBuyback)
  })
_sym_db.RegisterMessage(EventBuyback)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/NibiruChain/nibiru/x/stablecoin/types'
  _EVENTTRANSFER.fields_by_name['coin']._options = None
  _EVENTTRANSFER.fields_by_name['coin']._serialized_options = b'\310\336\037\000'
  _EVENTMINTSTABLE.fields_by_name['amount']._options = None
  _EVENTMINTSTABLE.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTBURNSTABLE.fields_by_name['amount']._options = None
  _EVENTBURNSTABLE.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTMINTNIBI.fields_by_name['amount']._options = None
  _EVENTMINTNIBI.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTBURNNIBI.fields_by_name['amount']._options = None
  _EVENTBURNNIBI.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTRECOLLATERALIZE.fields_by_name['in_coin']._options = None
  _EVENTRECOLLATERALIZE.fields_by_name['in_coin']._serialized_options = b'\310\336\037\000'
  _EVENTRECOLLATERALIZE.fields_by_name['out_coin']._options = None
  _EVENTRECOLLATERALIZE.fields_by_name['out_coin']._serialized_options = b'\310\336\037\000'
  _EVENTRECOLLATERALIZE.fields_by_name['coll_ratio']._options = None
  _EVENTRECOLLATERALIZE.fields_by_name['coll_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EVENTBUYBACK.fields_by_name['in_coin']._options = None
  _EVENTBUYBACK.fields_by_name['in_coin']._serialized_options = b'\310\336\037\000'
  _EVENTBUYBACK.fields_by_name['out_coin']._options = None
  _EVENTBUYBACK.fields_by_name['out_coin']._serialized_options = b'\310\336\037\000'
  _EVENTBUYBACK.fields_by_name['coll_ratio']._options = None
  _EVENTBUYBACK.fields_by_name['coll_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EVENTTRANSFER._serialized_start=103
  _EVENTTRANSFER._serialized_end=191
  _EVENTMINTSTABLE._serialized_start=193
  _EVENTMINTSTABLE._serialized_end=274
  _EVENTBURNSTABLE._serialized_start=276
  _EVENTBURNSTABLE._serialized_end=357
  _EVENTMINTNIBI._serialized_start=359
  _EVENTMINTNIBI._serialized_end=438
  _EVENTBURNNIBI._serialized_start=440
  _EVENTBURNNIBI._serialized_end=519
  _EVENTRECOLLATERALIZE._serialized_start=522
  _EVENTRECOLLATERALIZE._serialized_end=729
  _EVENTBUYBACK._serialized_start=732
  _EVENTBUYBACK._serialized_end=931
# @@protoc_insertion_point(module_scope)



class Network:
    def __init__(
        self,
        lcd_endpoint: str,
        grpc_endpoint: str,
        grpc_exchange_endpoint: str,
        chain_id: str,
        fee_denom: str,
        env: str,
    ):
        self.lcd_endpoint = lcd_endpoint
        self.grpc_endpoint = grpc_endpoint
        self.grpc_exchange_endpoint = grpc_exchange_endpoint
        self.chain_id = chain_id
        self.fee_denom = fee_denom
        self.env = env

    @classmethod
    def devnet(cls) -> "Network":
        raise NotImplementedError

    @classmethod
    def testnet(cls) -> "Network":
        raise NotImplementedError

    @classmethod
    def mainnet(cls) -> "Network":
        raise NotImplementedError

    @classmethod
    def local(cls) -> "Network":
        return cls(
            lcd_endpoint='http://localhost:1317',
            grpc_endpoint='localhost:9090',
            grpc_exchange_endpoint='localhost:9090',
            chain_id='nibiru-localnet-0',
            fee_denom='unibi',
            env='local'
        )

    def string(self):
        return self.env


from dataclasses import dataclass
from enum import Enum

from .proto.cosmos.base.v1beta1 import coin_pb2 as coin_pb


class TxType(Enum):
    SYNC = 1
    ASYNC = 2
    BLOCK = 3


class Side(Enum):
    BUY = 1
    SELL = 2


class Direction(Enum):
    ADD = 1
    REMOVE = 2


@dataclass
class PoolAsset:
    token: coin_pb.Coin
    weight: str


class TxConfig:
    def __init__(
        self, gas_wanted: int = 0, gas_multiplier: float = 0, gas_price: float = 0, tx_type: TxType = TxType.ASYNC
    ):
        '''
        Parameters:
            gas_wanted (int): Set the absolute gas_wanted to be used
            gas_multiplier (float): Set the gas multiplier that's being applied to the estimated gas, defaults to 1.25.
                                    If gas_wanted is set this property is ignored.
            gas_price(float): Set the gas price used to calculate the fee
            tx_type (TxType): Configure how to execute the tx, defaults to `ASYNC`
        '''
        self.gas_multiplier = gas_multiplier
        self.gas_wanted = gas_wanted
        self.gas_price = gas_price
        self.tx_type = tx_type



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from lockup.v1 import query_pb2 as lockup_dot_v1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LockedCoins = channel.unary_unary(
                '/nibiru.lockup.v1.Query/LockedCoins',
                request_serializer=lockup_dot_v1_dot_query__pb2.QueryLockedCoinsRequest.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_query__pb2.QueryLockedCoinsResponse.FromString,
                )
        self.Lock = channel.unary_unary(
                '/nibiru.lockup.v1.Query/Lock',
                request_serializer=lockup_dot_v1_dot_query__pb2.QueryLockRequest.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_query__pb2.QueryLockResponse.FromString,
                )
        self.LocksByAddress = channel.unary_unary(
                '/nibiru.lockup.v1.Query/LocksByAddress',
                request_serializer=lockup_dot_v1_dot_query__pb2.QueryLocksByAddress.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_query__pb2.QueryLocksByAddressResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LockedCoins(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Lock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocksByAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LockedCoins': grpc.unary_unary_rpc_method_handler(
                    servicer.LockedCoins,
                    request_deserializer=lockup_dot_v1_dot_query__pb2.QueryLockedCoinsRequest.FromString,
                    response_serializer=lockup_dot_v1_dot_query__pb2.QueryLockedCoinsResponse.SerializeToString,
            ),
            'Lock': grpc.unary_unary_rpc_method_handler(
                    servicer.Lock,
                    request_deserializer=lockup_dot_v1_dot_query__pb2.QueryLockRequest.FromString,
                    response_serializer=lockup_dot_v1_dot_query__pb2.QueryLockResponse.SerializeToString,
            ),
            'LocksByAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.LocksByAddress,
                    request_deserializer=lockup_dot_v1_dot_query__pb2.QueryLocksByAddress.FromString,
                    response_serializer=lockup_dot_v1_dot_query__pb2.QueryLocksByAddressResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.lockup.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LockedCoins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Query/LockedCoins',
            lockup_dot_v1_dot_query__pb2.QueryLockedCoinsRequest.SerializeToString,
            lockup_dot_v1_dot_query__pb2.QueryLockedCoinsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Lock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Query/Lock',
            lockup_dot_v1_dot_query__pb2.QueryLockRequest.SerializeToString,
            lockup_dot_v1_dot_query__pb2.QueryLockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocksByAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Query/LocksByAddress',
            lockup_dot_v1_dot_query__pb2.QueryLocksByAddress.SerializeToString,
            lockup_dot_v1_dot_query__pb2.QueryLocksByAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/v1beta1/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/params/v1beta1/params.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\"\x82\x01\n\x17ParameterChangeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x39\n\x07\x63hanges\x18\x03 \x03(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x00:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"A\n\x0bParamChange\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t:\x04\x98\xa0\x1f\x00\x42:Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\xa8\xe2\x1e\x01\x62\x06proto3')



_PARAMETERCHANGEPROPOSAL = DESCRIPTOR.message_types_by_name['ParameterChangeProposal']
_PARAMCHANGE = DESCRIPTOR.message_types_by_name['ParamChange']
ParameterChangeProposal = _reflection.GeneratedProtocolMessageType('ParameterChangeProposal', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERCHANGEPROPOSAL,
  '__module__' : 'cosmos.params.v1beta1.params_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.params.v1beta1.ParameterChangeProposal)
  })
_sym_db.RegisterMessage(ParameterChangeProposal)

ParamChange = _reflection.GeneratedProtocolMessageType('ParamChange', (_message.Message,), {
  'DESCRIPTOR' : _PARAMCHANGE,
  '__module__' : 'cosmos.params.v1beta1.params_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.params.v1beta1.ParamChange)
  })
_sym_db.RegisterMessage(ParamChange)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\250\342\036\001'
  _PARAMETERCHANGEPROPOSAL.fields_by_name['changes']._options = None
  _PARAMETERCHANGEPROPOSAL.fields_by_name['changes']._serialized_options = b'\310\336\037\000'
  _PARAMETERCHANGEPROPOSAL._options = None
  _PARAMETERCHANGEPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000'
  _PARAMCHANGE._options = None
  _PARAMCHANGE._serialized_options = b'\230\240\037\000'
  _PARAMETERCHANGEPROPOSAL._serialized_start=84
  _PARAMETERCHANGEPROPOSAL._serialized_end=214
  _PARAMCHANGE._serialized_start=216
  _PARAMCHANGE._serialized_end=281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15vpool/v1/params.proto\x12\x0fnibiru.vpool.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\x0e\n\x06Params:\x04\x98\xa0\x1f\x00\"\xf1\x01\n\x0b\x43urrentTWAP\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x41\n\tnumerator\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x64\x65nominator\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')



_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_CURRENTTWAP = DESCRIPTOR.message_types_by_name['CurrentTWAP']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'vpool.v1.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.Params)
  })
_sym_db.RegisterMessage(Params)

CurrentTWAP = _reflection.GeneratedProtocolMessageType('CurrentTWAP', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTTWAP,
  '__module__' : 'vpool.v1.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.CurrentTWAP)
  })
_sym_db.RegisterMessage(CurrentTWAP)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _CURRENTTWAP.fields_by_name['pair_id']._options = None
  _CURRENTTWAP.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _CURRENTTWAP.fields_by_name['numerator']._options = None
  _CURRENTTWAP.fields_by_name['numerator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['denominator']._options = None
  _CURRENTTWAP.fields_by_name['denominator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['price']._options = None
  _CURRENTTWAP.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._serialized_start=123
  _PARAMS._serialized_end=137
  _CURRENTTWAP._serialized_start=140
  _CURRENTTWAP._serialized_end=381
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epochs/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from epochs import genesis_pb2 as epochs_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x65pochs/query.proto\x12\x15nibiru.epochs.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14\x65pochs/genesis.proto\"\x18\n\x16QueryEpochsInfoRequest\"Q\n\x17QueryEpochsInfoResponse\x12\x36\n\x06\x65pochs\x18\x01 \x03(\x0b\x32 .nibiru.epochs.v1beta1.EpochInfoB\x04\xc8\xde\x1f\x00\".\n\x18QueryCurrentEpochRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"2\n\x19QueryCurrentEpochResponse\x12\x15\n\rcurrent_epoch\x18\x01 \x01(\x03\x32\xbe\x02\n\x05Query\x12\x92\x01\n\nEpochInfos\x12-.nibiru.epochs.v1beta1.QueryEpochsInfoRequest\x1a..nibiru.epochs.v1beta1.QueryEpochsInfoResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/nibiru/epochs/v1beta1/epochs\x12\x9f\x01\n\x0c\x43urrentEpoch\x12/.nibiru.epochs.v1beta1.QueryCurrentEpochRequest\x1a\x30.nibiru.epochs.v1beta1.QueryCurrentEpochResponse\",\x82\xd3\xe4\x93\x02&\x12$/nibiru/epochs/v1beta1/current_epochB.Z,github.com/NibiruChain/nibiru/x/epochs/typesb\x06proto3')



_QUERYEPOCHSINFOREQUEST = DESCRIPTOR.message_types_by_name['QueryEpochsInfoRequest']
_QUERYEPOCHSINFORESPONSE = DESCRIPTOR.message_types_by_name['QueryEpochsInfoResponse']
_QUERYCURRENTEPOCHREQUEST = DESCRIPTOR.message_types_by_name['QueryCurrentEpochRequest']
_QUERYCURRENTEPOCHRESPONSE = DESCRIPTOR.message_types_by_name['QueryCurrentEpochResponse']
QueryEpochsInfoRequest = _reflection.GeneratedProtocolMessageType('QueryEpochsInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEPOCHSINFOREQUEST,
  '__module__' : 'epochs.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.epochs.v1beta1.QueryEpochsInfoRequest)
  })
_sym_db.RegisterMessage(QueryEpochsInfoRequest)

QueryEpochsInfoResponse = _reflection.GeneratedProtocolMessageType('QueryEpochsInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEPOCHSINFORESPONSE,
  '__module__' : 'epochs.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.epochs.v1beta1.QueryEpochsInfoResponse)
  })
_sym_db.RegisterMessage(QueryEpochsInfoResponse)

QueryCurrentEpochRequest = _reflection.GeneratedProtocolMessageType('QueryCurrentEpochRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCURRENTEPOCHREQUEST,
  '__module__' : 'epochs.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.epochs.v1beta1.QueryCurrentEpochRequest)
  })
_sym_db.RegisterMessage(QueryCurrentEpochRequest)

QueryCurrentEpochResponse = _reflection.GeneratedProtocolMessageType('QueryCurrentEpochResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCURRENTEPOCHRESPONSE,
  '__module__' : 'epochs.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.epochs.v1beta1.QueryCurrentEpochResponse)
  })
_sym_db.RegisterMessage(QueryCurrentEpochResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/epochs/types'
  _QUERYEPOCHSINFORESPONSE.fields_by_name['epochs']._options = None
  _QUERYEPOCHSINFORESPONSE.fields_by_name['epochs']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['EpochInfos']._options = None
  _QUERY.methods_by_name['EpochInfos']._serialized_options = b'\202\323\344\223\002\037\022\035/nibiru/epochs/v1beta1/epochs'
  _QUERY.methods_by_name['CurrentEpoch']._options = None
  _QUERY.methods_by_name['CurrentEpoch']._serialized_options = b'\202\323\344\223\002&\022$/nibiru/epochs/v1beta1/current_epoch'
  _QUERYEPOCHSINFOREQUEST._serialized_start=163
  _QUERYEPOCHSINFOREQUEST._serialized_end=187
  _QUERYEPOCHSINFORESPONSE._serialized_start=189
  _QUERYEPOCHSINFORESPONSE._serialized_end=270
  _QUERYCURRENTEPOCHREQUEST._serialized_start=272
  _QUERYCURRENTEPOCHREQUEST._serialized_end=318
  _QUERYCURRENTEPOCHRESPONSE._serialized_start=320
  _QUERYCURRENTEPOCHRESPONSE._serialized_end=370
  _QUERY._serialized_start=373
  _QUERY._serialized_end=691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from common import common_pb2 as common_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16pricefeed/params.proto\x12\x13nibiru.pricefeed.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x13\x63ommon/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"7\n\x06Params\x12-\n\x05pairs\x18\x01 \x03(\x0b\x32\x18.nibiru.common.AssetPairB\x04\xc8\xde\x1f\x00\"V\n\x10OraclesMarshaler\x12\x42\n\x07oracles\x18\x01 \x03(\x0c\x42\x31\xfa\xde\x1f-github.com/cosmos/cosmos-sdk/types.AccAddress\"(\n\x13\x41\x63tivePairMarshaler\x12\x11\n\tis_active\x18\x01 \x01(\x08\"\xaf\x01\n\x0bPostedPrice\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x0e\n\x06oracle\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"j\n\x0c\x43urrentPrice\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xf1\x01\n\x0b\x43urrentTWAP\x12\x1b\n\x07pair_id\x18\x01 \x01(\tB\n\xe2\xde\x1f\x06PairID\x12\x41\n\tnumerator\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x64\x65nominator\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x35Z/github.com/NibiruChain/nibiru/x/pricefeed/types\xa8\xe2\x1e\x01\x62\x06proto3')



_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_ORACLESMARSHALER = DESCRIPTOR.message_types_by_name['OraclesMarshaler']
_ACTIVEPAIRMARSHALER = DESCRIPTOR.message_types_by_name['ActivePairMarshaler']
_POSTEDPRICE = DESCRIPTOR.message_types_by_name['PostedPrice']
_CURRENTPRICE = DESCRIPTOR.message_types_by_name['CurrentPrice']
_CURRENTTWAP = DESCRIPTOR.message_types_by_name['CurrentTWAP']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'pricefeed.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.Params)
  })
_sym_db.RegisterMessage(Params)

OraclesMarshaler = _reflection.GeneratedProtocolMessageType('OraclesMarshaler', (_message.Message,), {
  'DESCRIPTOR' : _ORACLESMARSHALER,
  '__module__' : 'pricefeed.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.OraclesMarshaler)
  })
_sym_db.RegisterMessage(OraclesMarshaler)

ActivePairMarshaler = _reflection.GeneratedProtocolMessageType('ActivePairMarshaler', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEPAIRMARSHALER,
  '__module__' : 'pricefeed.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.ActivePairMarshaler)
  })
_sym_db.RegisterMessage(ActivePairMarshaler)

PostedPrice = _reflection.GeneratedProtocolMessageType('PostedPrice', (_message.Message,), {
  'DESCRIPTOR' : _POSTEDPRICE,
  '__module__' : 'pricefeed.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.PostedPrice)
  })
_sym_db.RegisterMessage(PostedPrice)

CurrentPrice = _reflection.GeneratedProtocolMessageType('CurrentPrice', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTPRICE,
  '__module__' : 'pricefeed.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.CurrentPrice)
  })
_sym_db.RegisterMessage(CurrentPrice)

CurrentTWAP = _reflection.GeneratedProtocolMessageType('CurrentTWAP', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTTWAP,
  '__module__' : 'pricefeed.params_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.CurrentTWAP)
  })
_sym_db.RegisterMessage(CurrentTWAP)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types\250\342\036\001'
  _PARAMS.fields_by_name['pairs']._options = None
  _PARAMS.fields_by_name['pairs']._serialized_options = b'\310\336\037\000'
  _ORACLESMARSHALER.fields_by_name['oracles']._options = None
  _ORACLESMARSHALER.fields_by_name['oracles']._serialized_options = b'\372\336\037-github.com/cosmos/cosmos-sdk/types.AccAddress'
  _POSTEDPRICE.fields_by_name['pair_id']._options = None
  _POSTEDPRICE.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _POSTEDPRICE.fields_by_name['price']._options = None
  _POSTEDPRICE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSTEDPRICE.fields_by_name['expiry']._options = None
  _POSTEDPRICE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _CURRENTPRICE.fields_by_name['pair_id']._options = None
  _CURRENTPRICE.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _CURRENTPRICE.fields_by_name['price']._options = None
  _CURRENTPRICE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['pair_id']._options = None
  _CURRENTTWAP.fields_by_name['pair_id']._serialized_options = b'\342\336\037\006PairID'
  _CURRENTTWAP.fields_by_name['numerator']._options = None
  _CURRENTTWAP.fields_by_name['numerator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['denominator']._options = None
  _CURRENTTWAP.fields_by_name['denominator']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CURRENTTWAP.fields_by_name['price']._options = None
  _CURRENTTWAP.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._serialized_start=150
  _PARAMS._serialized_end=205
  _ORACLESMARSHALER._serialized_start=207
  _ORACLESMARSHALER._serialized_end=293
  _ACTIVEPAIRMARSHALER._serialized_start=295
  _ACTIVEPAIRMARSHALER._serialized_end=335
  _POSTEDPRICE._serialized_start=338
  _POSTEDPRICE._serialized_end=513
  _CURRENTPRICE._serialized_start=515
  _CURRENTPRICE._serialized_end=621
  _CURRENTTWAP._serialized_start=624
  _CURRENTTWAP._serialized_end=865
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.feegrant.v1beta1 import feegrant_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_feegrant__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/feegrant/v1beta1/query.proto\x12\x17\x63osmos.feegrant.v1beta1\x1a&cosmos/feegrant/v1beta1/feegrant.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\"9\n\x15QueryAllowanceRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\"K\n\x16QueryAllowanceResponse\x12\x31\n\tallowance\x18\x01 \x01(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\"e\n\x16QueryAllowancesRequest\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8a\x01\n\x17QueryAllowancesResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"n\n\x1fQueryAllowancesByGranterRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n QueryAllowancesByGranterResponse\x12\x32\n\nallowances\x18\x01 \x03(\x0b\x32\x1e.cosmos.feegrant.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x9f\x04\n\x05Query\x12\xac\x01\n\tAllowance\x12..cosmos.feegrant.v1beta1.QueryAllowanceRequest\x1a/.cosmos.feegrant.v1beta1.QueryAllowanceResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}\x12\xa6\x01\n\nAllowances\x12/.cosmos.feegrant.v1beta1.QueryAllowancesRequest\x1a\x30.cosmos.feegrant.v1beta1.QueryAllowancesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/feegrant/v1beta1/allowances/{grantee}\x12\xbd\x01\n\x13\x41llowancesByGranter\x12\x38.cosmos.feegrant.v1beta1.QueryAllowancesByGranterRequest\x1a\x39.cosmos.feegrant.v1beta1.QueryAllowancesByGranterResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/feegrant/v1beta1/issued/{granter}B)Z\'github.com/cosmos/cosmos-sdk/x/feegrantb\x06proto3')



_QUERYALLOWANCEREQUEST = DESCRIPTOR.message_types_by_name['QueryAllowanceRequest']
_QUERYALLOWANCERESPONSE = DESCRIPTOR.message_types_by_name['QueryAllowanceResponse']
_QUERYALLOWANCESREQUEST = DESCRIPTOR.message_types_by_name['QueryAllowancesRequest']
_QUERYALLOWANCESRESPONSE = DESCRIPTOR.message_types_by_name['QueryAllowancesResponse']
_QUERYALLOWANCESBYGRANTERREQUEST = DESCRIPTOR.message_types_by_name['QueryAllowancesByGranterRequest']
_QUERYALLOWANCESBYGRANTERRESPONSE = DESCRIPTOR.message_types_by_name['QueryAllowancesByGranterResponse']
QueryAllowanceRequest = _reflection.GeneratedProtocolMessageType('QueryAllowanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCEREQUEST,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowanceRequest)
  })
_sym_db.RegisterMessage(QueryAllowanceRequest)

QueryAllowanceResponse = _reflection.GeneratedProtocolMessageType('QueryAllowanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCERESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowanceResponse)
  })
_sym_db.RegisterMessage(QueryAllowanceResponse)

QueryAllowancesRequest = _reflection.GeneratedProtocolMessageType('QueryAllowancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESREQUEST,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesRequest)
  })
_sym_db.RegisterMessage(QueryAllowancesRequest)

QueryAllowancesResponse = _reflection.GeneratedProtocolMessageType('QueryAllowancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESRESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesResponse)
  })
_sym_db.RegisterMessage(QueryAllowancesResponse)

QueryAllowancesByGranterRequest = _reflection.GeneratedProtocolMessageType('QueryAllowancesByGranterRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESBYGRANTERREQUEST,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesByGranterRequest)
  })
_sym_db.RegisterMessage(QueryAllowancesByGranterRequest)

QueryAllowancesByGranterResponse = _reflection.GeneratedProtocolMessageType('QueryAllowancesByGranterResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLOWANCESBYGRANTERRESPONSE,
  '__module__' : 'cosmos.feegrant.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.feegrant.v1beta1.QueryAllowancesByGranterResponse)
  })
_sym_db.RegisterMessage(QueryAllowancesByGranterResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/cosmos/cosmos-sdk/x/feegrant'
  _QUERY.methods_by_name['Allowance']._options = None
  _QUERY.methods_by_name['Allowance']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/feegrant/v1beta1/allowance/{granter}/{grantee}'
  _QUERY.methods_by_name['Allowances']._options = None
  _QUERY.methods_by_name['Allowances']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/feegrant/v1beta1/allowances/{grantee}'
  _QUERY.methods_by_name['AllowancesByGranter']._options = None
  _QUERY.methods_by_name['AllowancesByGranter']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/feegrant/v1beta1/issued/{granter}'
  _QUERYALLOWANCEREQUEST._serialized_start=178
  _QUERYALLOWANCEREQUEST._serialized_end=235
  _QUERYALLOWANCERESPONSE._serialized_start=237
  _QUERYALLOWANCERESPONSE._serialized_end=312
  _QUERYALLOWANCESREQUEST._serialized_start=314
  _QUERYALLOWANCESREQUEST._serialized_end=415
  _QUERYALLOWANCESRESPONSE._serialized_start=418
  _QUERYALLOWANCESRESPONSE._serialized_end=556
  _QUERYALLOWANCESBYGRANTERREQUEST._serialized_start=558
  _QUERYALLOWANCESBYGRANTERREQUEST._serialized_end=668
  _QUERYALLOWANCESBYGRANTERRESPONSE._serialized_start=671
  _QUERYALLOWANCESBYGRANTERRESPONSE._serialized_end=818
  _QUERY._serialized_start=821
  _QUERY._serialized_end=1364
# @@protoc_insertion_point(module_scope)
